@@ -89,6 +89,11 @@
 				      cargo_type => 'leaf',
 				      cargo_args => {value_type => 'string'},
 				    },
+	       "list_XLeds" => { type => 'list',
+			    cargo_type => 'leaf',
+			    cargo_args => { value_type => 'integer', 
+					    min => 1, max => 3 } ,
+			  },
 	       [qw/hash_a hash_b/] => { type => 'hash',
 			  index_type => 'string',
 			  cargo_type => 'leaf',
