@@ -1,9 +1,8 @@
 # $Author: ddumont $
-# $Date: 2008-02-26 13:36:21 $
-# $Name: not supported by cvs2svn $
-# $Revision: 1.4 $
+# $Date: 2008-04-03 19:12:21 +0200 (Thu, 03 Apr 2008) $
+# $Revision: 583 $
 
-#    Copyright (c) 2007 Dominique Dumont.
+#    Copyright (c) 2007-2008 Dominique Dumont.
 #
 #    This file is part of Config-Model-Itself.
 #
@@ -44,32 +43,14 @@
 	   built_in => 'normal',
 	  },
 
-       'value_type' 
-       => { type => 'leaf',
-	    level => 'hidden',
-	    'warp'
-	    => { follow => { 't' => '?type' , ct => '?cargo_type' },
-		 'rules'
-		 => [ '$t eq "leaf" or $ct eq "leaf"' 
-		      => {
-			  value_type => 'enum',
-			  choice => [qw/boolean enum integer reference
-					enum_integer number uniline string/],
-			  level => 'normal',
-			  #mandatory => 1,
-			 }
-		    ]
-	       }
-	  },
-
        [qw/default built_in/] 
        => { type => 'leaf',
 	    level => 'hidden',
-	    warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	    value_type => 'uniline',
+	    warp => {  follow => { 't' => '?type' },
 		       'rules'
-		       => [ '$t eq "leaf" or $ct eq "leaf"' 
+		       => [ '$t eq "leaf"' 
 			    => {
-				value_type => 'uniline',
 				level => 'normal',
 			       }
 			  ]
@@ -80,9 +61,9 @@
        => { type => 'leaf',
 	    level => 'hidden',
 	    value_type => 'uniline' ,
-	    warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	    warp => {  follow => { 't' => '?type'},
 		       'rules'
-		       => [ '$t eq "hash" or $ct eq "hash"' 
+		       => [ '$t eq "hash"' 
 			    => {
 				level => 'normal',
 			       }
@@ -94,9 +75,9 @@
        => { type => 'leaf',
 	    level => 'hidden',
 	    value_type => 'boolean' ,
-	    warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	    warp => {  follow => { 't' => '?type' },
 		       'rules'
-		       => [ '$t eq "hash" or $ct eq "hash"' 
+		       => [ '$t eq "hash"'
 			    => {
 				level => 'normal',
 			       }
@@ -110,9 +91,9 @@
 	    level => 'hidden',
 	    cargo_type => 'leaf',
 	    cargo_args => { value_type => 'string'} ,
-	    warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	    warp => {  follow => { 't' => '?type' },
 		       'rules'
-		       => [ '$t eq "hash" or $ct eq "hash"' 
+		       => [ '$t eq "hash"'
 			    => {
 				level => 'normal',
 			       }
@@ -126,9 +107,9 @@
 	    index_type => 'string',
 	    cargo_type => 'leaf',
 	    cargo_args => { value_type => 'string'} ,
-	    warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	    warp => {  follow => { 't' => '?type' },
 		       'rules'
-		       => [ '$t eq "hash" or $ct eq "hash"' 
+		       => [ '$t eq "hash"'
 			    => {
 				level => 'normal',
 			       }
@@ -138,12 +119,12 @@
 
        [qw/convert/] 
        => { type => 'leaf',
+	    value_type => 'enum',
 	    level => 'hidden',
-	    warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	    warp => {  follow => { 't' => '?type'},
 		       'rules'
-		       => [ '$t eq "leaf" or $ct eq "leaf"' 
+		       => [ '$t eq "leaf"'
 			    => {
-				value_type => 'enum',
 				choice => [qw/uc lc/],
 				level => 'normal',
 			       }
@@ -151,25 +132,39 @@
 		    }
 	  },
 
-       [qw/min max max_nb/]
+       [qw/min max/]
        => { type => 'leaf',
+	    value_type => 'integer',
 	    level => 'hidden',
 	    warp => { follow => {
 				 'type'  => '?type',
-				 ct => '?cargo_type' ,
 				 'vtype' => '?value_type' ,
 				},
 		     'rules'
-		      => [ '($type eq "hash" or $ct eq "hash" )
+		      => [ '$type eq "hash"
                             or
-                            (    ( $type eq "leaf" or $ct eq "leaf") 
+                            (    $type eq "leaf" 
                              and (    $vtype eq "integer" 
                                    or $vtype eq "number" 
-                                   or $vtype eq "enum_integer" 
                                  )
                             ) '
 			   => {
-			       value_type => 'integer',
+			       level => 'normal',
+			      }
+			 ]
+		    }
+	  },
+
+       'max_nb'
+       => { type => 'leaf',
+	    level => 'hidden',
+	    value_type => 'integer',
+	    warp => { follow => {
+				 'type'  => '?type',
+				},
+		     'rules'
+		      => [ '$type eq "hash"'
+			   => {
 			       level => 'normal',
 			      }
 			 ]
@@ -179,10 +174,10 @@
        'mandatory'
        => { type => 'leaf',
 	    level => 'hidden',
+	    value_type => 'boolean',
 	    warp => { follow => '?type',
 		     'rules'
 		      => { 'leaf' => {
-				      value_type => 'boolean',
 				      built_in   => 0,
 				      level => 'normal',
 				     }
@@ -194,18 +189,18 @@
        => { type => 'list',
 	    cargo_type => 'leaf',
 	    level => 'hidden',
-	    warp => { follow => { t => '?type',
+	    warp => { follow => { t  => '?type',
 				  vt => '?value_type',
 				},
 		      'rules'
-		      => [ '  ($t eq "leaf" and $vt =~ /enum/ )
+		      => [ '  ($t eq "leaf" and $vt eq "enum" )
                             or $t eq "check_list"' 
 			   => {
 			       level => 'normal',
 			      } ,
 			 ]
 		    },
-	    'cargo_args' =>  { value_type => 'uniline'}
+	    'cargo_args' =>  { value_type => 'uniline'},
 	  },
 
        [qw/default_list/] 
@@ -223,7 +218,6 @@
 	    cargo_args => {
 			   value_type => 'reference',
 			   refer_to => '- choice',
-			   level => 'normal',
 			  }
 	  },
 
@@ -233,8 +227,9 @@
 	   level => 'hidden',
 	   value_type => 'reference', 
 	   refer_to => '! class',
-	   warp => {  follow => { t => '?type', ct => '?cargo_type'},
-		      rules  => [ '$t eq "node" or $t eq "warped_node" or $ct eq "node"' 
+	   warp => {  follow => { t => '?type' , ct => '?cargo_type'},
+		      rules  => [ '  $t  eq "node" or $t  eq "warped_node"
+                                  or $ct eq "node" or $ct eq "warped_node"' 
 				  => { 
 				       # should be able to warp refer_to ??
 				       level => 'normal',
@@ -243,14 +238,14 @@
 		   }
 	  },
 
-       'replace'
+       [qw/replace help/]
        => {
 	   type => 'hash',
 	   index_type => 'string',
 	   level => 'hidden',
-	   warp => {  follow => { 't' => '?type' , ct => '?cargo_type' },
+	   warp => {  follow => { 't' => '?type' },
 		      'rules'
-		      => [ '$t eq "leaf" or $ct eq "leaf"' 
+		      => [ '$t eq "leaf"'
 			   => {
 			       level => 'normal',
 			      }
@@ -261,16 +256,6 @@
 	   # enum value...
 	   cargo_args => { value_type => 'string' } ,
 	  },
-
-       'help'
-       => {
-	   type => 'hash',
-	   index_type => 'string',
-	   cargo_type => 'leaf',
-	   cargo_args => { value_type => 'string' } ,
-	  }
-
-
       ],
 
    'description' 
@@ -279,18 +264,19 @@
        level => 'Used to highlight important parameter or to hide others. Hidden parameter are mostly used to hide features that are unavailable at start time. They can be made available later using warp mechanism',
        value_type => 'specify the type of a leaf element.',
        default => 'Specify default value. This default value will be written in the configuration data',
-       built_in => 'Another way to specify a default value. But this default value is considered as "built_in" the applicaiton and is not written in the configuration data (unless modified)',
+       built_in => 'Another way to specify a default value. But this default value is considered as "built_in" the application and is not written in the configuration data (unless modified)',
        follow_keys_from => 'this hash will contain the same keys as the hash pointed by the path string',
        allow_keys_from =>'this hash will allow keys from the keys of the hash pointed by the path string', 
        ordered => 'keep track of the order of the elements of this hash',
        default_keys => 'default keys hashes.',
        auto_create => 'always create a set of keys',
        allow_keys => 'specify a set of allowed keys',
-       default_with_init => 'specify a set of keys to create and initialisaiton on some elements . E.g. \' foo => "X=Av Y=Bv", bar => "Y=Av Z=Cz"\' ',
+       default_with_init => 'specify a set of keys to create and initialization on some elements . E.g. \' foo => "X=Av Y=Bv", bar => "Y=Av Z=Cz"\' ',
        convert => 'When stored, the value will be converted to uppercase (uc) or lowercase (lc).',
        choice => 'Specify the possible values',
-       default_list => 'Speicfy items checked by default',
+       default_list => 'Specify items checked by default',
        help => 'Specify help string specific to possible values. E.g for "light" value, you could write " red => \'stop\', green => \'walk\' ',
+       replace => 'Used for enum to substitute one value with another. This parameter must be used to enable user to upgrade a configuration with obsolete values. The old value is the key of the hash, the new one is the value of the hash',
       ],
   ],
 
